widgetsnbextension: Jupyter notebook extension for interactive HTML widgets
===========================================================================

Description
-----------

Interactive HTML widgets for Jupyter notebooks.
